@@ -55,7 +55,7 @@ class InvokerImpl(Invoker):
             else:
                 self._func()
         except Exception as e:
-            raise Exception("Error occurred executing function " + self.fullname + "(...)") from e
+            raise Exception("Error occurred executing function " + self.fullname + "(...)" + " " + str(e)) from e
 
 
 class AsyncInvokerWrapper(Invoker):
@@ -100,8 +100,8 @@ class InvokerManager:
     def running_invocations(self) -> List[str]:
         with self.__lock:
             info = []
-            for id, running_since in self.__running_invocations.items():
-                info.append(id + " (since " + str((datetime.now() - running_since)))
+            for invoker, running_since in self.__running_invocations.items():
+                info.append(str(invoker) + " (since " + str((datetime.now() - running_since)) + ")")
             return sorted(info)
 
     def add_listener(self, listener):
@@ -153,7 +153,7 @@ class InvokerManager:
                         logging.debug("[runner" + str(runner_id) + "] invoking " + str(invocation))
                         invocation.invoke()
                     except Exception as e:
-                        logging.warning("[runner" + str(runner_id) + "] error occurred calling " + str(invocation) + " " + str(e))
+                        logging.warning("[runner" + str(runner_id) + "] error occurred calling " + str(invocation) + " " + str(e), e)
                     finally:
                         self.deregister_running(invocation)
                 else:
